@@ -27,8 +27,13 @@ if __name__ == "__main__":
 
 DEFAULT_ENV = """DEBUG=True
 INTERNAL_IPS=127.0.0.1
+ALLOWED_HOSTS=
 SECRET_KEY="""
 
+DEFAULT_WATCHMAN_CONFIG = """{
+  "ignore_dirs": ["node_modules"]
+}"""
+
 
 def _run_manangement_command(command_name, *args):
     current_directory = getcwd()
@@ -78,6 +83,9 @@ def create():
         click.secho("Creating .env...", fg="yellow")
         Path(".env").write_text(DEFAULT_ENV + get_random_secret_key())
 
+        click.secho("Creating .watchmanconfig...", fg="yellow")
+        Path(".watchmanconfig").write_text(DEFAULT_WATCHMAN_CONFIG)
+
         click.secho("Creating content directory...", fg="yellow")
         Path("content").mkdir(exist_ok=True)
         (Path("content") / "index.md").write_text("# index.md")
@@ -102,8 +110,14 @@ def play(port):
 
 
 @click.command(help="Generates HTML output (record | rec | build).")
-def record():
-    _run_manangement_command("build")
+@click.option("--force/--no-force", default=False, help="Force HTML generation")
+def record(force):
+    args = []
+
+    if force:
+        args = ["--force"]
+
+    _run_manangement_command("build", *args)
 
 
 cli.add_command(create)
